SingleCenteredMultiChildLayout class

A layout widget that positions the given widgets at the center. This widget allows for a central widget and optionally top, bottom, left, and right widgets.

Inheritance

Constructors

SingleCenteredMultiChildLayout(Widget centeredWidget, {Widget? bottomWidget, Widget? topWidget, Widget? leftWidget, Widget? rightWidget, double topGap = 0, double bottomGap = 0, double leftGap = 0, double rightGap = 0, Key? key})
Constructor for SingleCenteredMultiChildLayout. centeredWidget is required, while the other widgets and gaps are optional.
const

Properties

bottomGap double
The gap between the bottom widget and the centered widget. Default is 0.
final
bottomWidget Widget?
An optional widget to be positioned at the bottom.
final
centeredWidget Widget
The widget to be positioned at the center.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftGap double
The gap between the left widget and the centered widget. Default is 0.
final
leftWidget Widget?
An optional widget to be positioned on the left.
final
rightGap double
The gap between the right widget and the centered widget. Default is 0.
final
rightWidget Widget?
An optional widget to be positioned on the right.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topGap double
The gap between the top widget and the centered widget. Default is 0.
final
topWidget Widget?
An optional widget to be positioned at the top.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited