CenteredLayoutDelegate class
A MultiChildLayoutDelegate that positions children in a centered layout with optional gaps around the centered widget.
- Inheritance
-
- Object
- MultiChildLayoutDelegate
- CenteredLayoutDelegate
Constructors
- CenteredLayoutDelegate({double topGap = 0, double bottomGap = 0, double leftGap = 0, double rightGap = 0})
- Creates a CenteredLayoutDelegate with optional gap parameters. All gaps default to 0 if not provided.
Properties
- bottomGap → double
-
The gap between the bottom widget and the centered widget. Default is 0.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leftGap → double
-
The gap between the left widget and the centered widget. Default is 0.
final
- rightGap → double
-
The gap between the right widget and the centered widget. Default is 0.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topGap → double
-
The gap between the top widget and the centered widget. Default is 0.
final
Methods
-
getSize(
BoxConstraints constraints) → Size -
Override this method to return the size of this object given the
incoming constraints.
inherited
-
hasChild(
Object childId) → bool -
True if a non-null LayoutChild was provided for the specified id.
inherited
-
layoutChild(
Object childId, BoxConstraints constraints) → Size -
Ask the child to update its layout within the limits specified by
the constraints parameter. The child's size is returned.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performLayout(
Size size) → void -
Override this method to lay out and position all children given this
widget's size.
override
-
positionChild(
Object childId, Offset offset) → void -
Specify the child's origin relative to this origin.
inherited
-
shouldRelayout(
covariant CenteredLayoutDelegate oldDelegate) → bool -
Override this method to return true when the children need to be
laid out.
override
-
toString(
) → String -
Override this method to include additional information in the
debugging data printed by debugDumpRenderTree and friends.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited